@@ -1,14 +1,14 @@
 # plot a vector of aspect measurements, with units of degrees, measured via compass
-aspect.plot <- function(p, p.bins=60, p.bw=30, stack=TRUE, p.axis=seq(0, 350, by=10), plot.title=NULL, line.col='RoyalBlue', line.lwd=1, line.lty=2, arrow.col=line.col, arrow.lwd=1, arrow.lty=1, ...) {
+aspect.plot <- function(p, q=c(0.05, 0.5, 0.95), p.bins=60, p.bw=30, stack=TRUE, p.axis=seq(0, 350, by=10), plot.title=NULL, line.col='RoyalBlue', line.lwd=1, line.lty=2, arrow.col=line.col, arrow.lwd=1, arrow.lty=1, arrow.length=0.15, ...) {
 	# remove NA
 	p <- na.omit(p)
 	
 	# make a circular class object: using native degrees, template sets zero and direction
-	c.p <- circular(p, units='degrees', template="geographics")
-	
-	# compute the mean
-	m.p <- mean(c.p)
-	
+	c.p <- circular(p, units='degrees', template="geographics", modulo='2pi')
+  
+  # compute quantiles
+	q.p <- quantile(c.p, probs=q)
+  
 	# compute mean resultant length
 	rho.p <- rho.circular(c.p)
 	
@@ -27,9 +27,12 @@ aspect.plot <- function(p, p.bins=60, p.bw=30, stack=TRUE, p.axis=seq(0, 350, by
 	# annotate north
 	text(0, 1.125, 'North', cex=0.85, font=1)
 	
-	# annotate mean with an arrow
-	arrows.circular(m.p, shrink=rho.p, length=0.15, col=arrow.col, lwd=arrow.lwd, lty=arrow.lty)
+	# annotate stats with a arrows
+	arrows.circular(q.p, shrink=rho.p, length=arrow.length, col=arrow.col, lwd=arrow.lwd, lty=arrow.lty)
 	
 	# add title
 	text(0, -0.25, plot.title, cex=0.85, font=2)
+  
+  # invisibly return stats
+  invisible(q.p)
 }
\ No newline at end of file
